#ifndef APPLET_H
#define APPLET_H

#include <QtGui/QWidget>
#include <QSystemTrayIcon>
#include <QMenu>
#include <QIcon>
#include <QAction>
#include <QRect>
#include <QDesktopWidget>
#include <QTimer>
#include <QPixmap>
#include <QIcon>
#include <QMessageBox>
#include <QAbstractButton>
#include <QLibrary>
#include <QList>
#include <QListIterator>
#include <QDir>
#include <QFileInfo>
#include <QFileInfoList>
#include <QRegExp>
#include <QSettings>

class Monitor;
class GenerateLog;
class Settings;
class Bubble;
class FirstRunWizard;
class HelpDialog;

extern const QString UBUDSL_PREFIX;

class Applet : public QSystemTrayIcon
{
    Q_OBJECT
public:
    typedef QList<QLibrary*> ModulesList;
    typedef QListIterator<QLibrary*> ModulesListIterator;

    Applet( QWidget *parent = 0 );
    ~Applet();

    void showMessage( const QString &title, const QString &message );
    
    QMenu *m_pluginsMenu;
    //void addModuleAction( QAction *action );
    //void removeModuleAction( QAction *action );
    QSettings m_settings;

private:
    enum Message
    {
        Connecting,
        ConnectionTimeout,
        RestartingModem,
        ConnectionTerminated,
        NoDaemon,
        IncorrectDNS,
        OpenDNS_Success,
        OpenDNS_Failed,
        Synchronising,
        SynchronisationFailed,
        CompilingDriver,
        CompilationFailed,
        CompilationSucceed,
        RestartingModemOnHangUp,
        FirstRun
    };

    void showMessage( Message msg );
    bool addToAutostart();
    bool removeFromAutostart();
    bool getIsInAutostart();

    static const QString desktopFileName;
    static const QString autostartPath;

    bool m_daemonOk;

    QMenu   *m_menu;
    QAction *m_actionQuit;
    QAction *m_actionHide;
    QAction *m_actionGenerateLog;
    QAction *m_actionSettings;
    QAction *m_actionConnect;
    QAction *m_actionReconnect;
    QAction *m_actionRestartModem;
    QAction *m_actionAutostart;
    QAction *m_separator1;
    QAction *m_separator2;
//    QAction *m_separator3;

    QIcon iconConnected;
    QIcon iconConnecting;
    QIcon iconDisconnected;
    QIcon iconConnect;
    QIcon iconDisconnect;
    QIcon iconReconnect;
    QIcon iconHide;
    QIcon iconNoDaemon;
    QIcon iconNoModem;
    QIcon iconShow;

    QMessageBox     *m_newModemMsgBox;
    QAbstractButton *m_btnYes;

    QTimer *m_connectingTimer;
    QTimer *m_timer;

    Monitor     *m_monitor;
    GenerateLog *m_generateLog;
    Settings    *m_settingsDialog;
    Bubble      *m_bubble;
    HelpDialog  *m_helpDialog;

    ModulesList m_modules;
    QList<QAction *> m_modulesActions;

private slots:
    void showHideMonitor();
    void clicked( QSystemTrayIcon::ActivationReason reason );
    void checkState( bool firstTime = true );
    void enableGenerateLog();
    void disableGenerateLog();
    void establishingConnection();
    void connectionTimeout();
    void connectionEstablished();
    void restartModemStarted();
    void restartModemFinished() {
        m_actionRestartModem->setEnabled( true );
    }
    void restartModem();
    void connectionTerminated( const bool message = true );
    void showSettings();
    void applySettings();
    void checkDaemonConnection();
    void connecting();
    void synchronising() {
        showMessage( Synchronising );
    }
    void synchronisationFailed();
    void modemPlugged( const QString &name );
    void newModemPlugged( const QString &name );
    void modemUnplugged();
    void incorrectDNS();
    void settingOpenDNS( const bool success );
    void newModemUnplugged();
    void accountDataChanged( const bool success );
    void invalidAccountData();
    void compilingDriver();
    void compilationFinished( const bool finished );
    void modemStillHangsUp();
    void PADOTimeout();
    void restartOnModemHangUp() {
        showMessage( RestartingModemOnHangUp );
    }
    void showNoDaemonMessage();
    void loadModules();
    void unloadModules();
    void setConnectionState( const int &state );
    void autostartActionTriggered();
    void firstRun();
signals:
    void quit();
    void playSndConnected();
    void playSndDisconnected();
    void playSndError();
    void playSndPlugged();
    void playSndUnplugged();
};

#endif // APPLET_H
