#include "FirstRunWizard.h"
#include <QHBoxLayout>

FirstRunWizard::FirstRunWizard( QSettings *appletSettings, QWidget *parent )
        : QWizard( parent ),
        appletSettings( appletSettings )
{
    setAttribute( Qt::WA_QuitOnClose, false );
    setWindowTitle( tr( "UbuDSL Applet - First Run Wizard" ) );

    setWizardStyle( QWizard::MacStyle );
    setPixmap( QWizard::BackgroundPixmap, QPixmap( ":images/semitransparent_logo.png" ) );
    setOptions( QWizard::NoBackButtonOnStartPage|QWizard::CancelButtonOnLeft );

    setButtonText( QWizard::BackButton,   tr( "&Back" ) );
    setButtonText( QWizard::NextButton,   tr( "&Next" ) );
    setButtonText( QWizard::CancelButton, tr( "&Cancel" ) );
    setButtonText( QWizard::FinishButton, tr( "&Finish" ) );

    autostartCheckBox = new QCheckBox( tr( "Yes, run the Applet when I log in." ) );
    passwordCheckBox  = new QCheckBox( tr( "Yes, I want the service password to be shown there." ) );

    delaySpinBox = new QSpinBox();
    delayLabel   = new QLabel( tr( "Delay:" ) );

    delaySpinBox->setRange( 0, 20 );
    delaySpinBox->setValue( 10 );
    delaySpinBox->setSuffix( "s" );

    QHBoxLayout *hboxLayout = new QHBoxLayout();

    hboxLayout->addWidget( delayLabel );
    hboxLayout->addWidget( delaySpinBox );

    QString firstPageText  = tr( "It seems that you have run the Applet first time. "
                                 "This wizard will help you configure this simple applet. "
                                 "Please answer a few simple questions in the next steps." );

    QString secondPageText = tr( "Would you like to run the Applet when you log in?" );

    QString thirdPageText  = tr( "Would you like the service password to be shown when "
                                 "you open the Settings dialog?" );

    QString fourthPageText = tr( "Please set the delay time before running the Applet "
                                 "when the Applet's autostart option is active." );

    QString fifthPageText  = tr( "All the needed informations have been gathered and "
                                 "now you can start using the Applet.\n\n"
                                 "This is an open source software and you may help "
                                 "improving it by your support. You can find out how "
                                 "to do this by opening the About dialog." );

    addPage( new WizardPage( tr( "Welcome" ),         firstPageText ) );
    addPage( new WizardPage( tr( "Autostart" ),       secondPageText, autostartCheckBox ) );
    addPage( new WizardPage( tr( "Password" ),        thirdPageText,  passwordCheckBox ) );
    addPage( new WizardPage( tr( "Autostart delay" ), fourthPageText, hboxLayout ) );
    addPage( new WizardPage( tr( "Finish" ),          fifthPageText ) );
}


FirstRunWizard::~FirstRunWizard()
{
    appletSettings->setValue( "autostart",     autostartCheckBox->isChecked() );
    appletSettings->setValue( "show_password", passwordCheckBox->isChecked() );
    appletSettings->setValue( "applet_delay",  delaySpinBox->value() );
}

WizardPage::WizardPage( QString title, QString &message, QWidget *customWidget, QWidget *parent )
        : QWizardPage( parent )
{
    setTitle( title );

    labelTop = new QLabel( message );
    labelTop->setWordWrap( true );

    QVBoxLayout *layout = new QVBoxLayout();
    layout->addWidget( labelTop );

    if ( customWidget )
        layout->addWidget( customWidget );

    setLayout( layout );
}

WizardPage::WizardPage( QString title, QString &message, QLayout *customWidgets, QWidget *parent )
        : QWizardPage( parent )
{
    setTitle( title );

    labelTop = new QLabel( message );
    labelTop->setWordWrap( true );

    QVBoxLayout *layout = new QVBoxLayout();
    layout->addWidget( labelTop );
    layout->addLayout( customWidgets );

    setLayout( layout );
}

