#include "HelpDialog.h"

#include <QWidget>

HelpDialog::HelpDialog( QWidget *parent )
: QDialog( parent )
{
    ui.setupUi( this );
    resize( sizeHint() );
    setAttribute( Qt::WA_QuitOnClose, false );

    connect( ui.btnNext, SIGNAL( clicked() ), this, SLOT( next() ) );
    connect( ui.btnPrevious, SIGNAL( clicked() ), this, SLOT( previous() ) );

    initHelpList();
    viewHelp();
}

HelpDialog::~HelpDialog()
{

}

void HelpDialog::initHelpList()
{
    helpList.clear();

    Help h;

    h.problem = "<b><i>" + tr( "Modem is synchronised, connection is established but I can't browse websites." ) + "</i></b>";
    h.solution = tr( "a) Probably this is a fault of the DNS servers. Try to use OpenDNS servers - "
                     "open terminal and perform these commands: "
                     "<blockquote>sudo rm -f /etc/resolv.conf<br>"
                     "sudo ubudsl.bin --set-opendns</blockquote> "
                     "b) If you use Ubuntu and your browser is Firefox, the web browser may be run in "
                     "the offline mode. To switch to the online mode, simply uncheck the <i>Work Offline</i> "
                     "position in the <i>File</i> menu.<br><br>"
                     "<font size=\"-2\"><i>ATTENTION:</i> If a command starts with sudo, after its confirmation "
                     "you may have to enter your password, which is invisible while typing.</font>" );

    helpList << h;

    h.problem = "<b><i>" + tr( "Modem is synchronised but there is no connection." ) + "</i></b>";
    h.solution = tr( "In this case you have to try to unplug the modem, wait a few seconds, "
                     "plug the modem in and wait to modem synchronise. Then try to connect.<br><br>"
                     "If it still doesn't work, please generate log and send it at "
                     "<i>ubudsl@gmail.com</i>." );

    helpList << h;

    h.problem = "<b><i>" + tr( "I have chosen the autostart applet option but it doesn't work at all." ) + "</i></b>";
    h.solution = tr( "Try to remove the applet's configuration directory: "
                     "<blockquote>rm -rf ~/.config/UbuDSL ~/.config/autostart/ubudsl_applet.desktop</blockquote> "
                     "Then restart the applet." );

    helpList << h;

    h.problem = "<b><i>" + tr( "I have a problem that is not described here." ) + "</i></b>";
    h.solution = tr( "You can find more problems and solutions on the project's website: "
                     "<a href=\"http://ubudsl.com\">www.ubudsl.com</a> (the FAQ tab)." );

    helpList << h;
}

void HelpDialog::viewHelp( const int idx )
{
    if ( idx >= helpList.count() || idx < 0 )
        return;

    m_idx = idx;

    ui.problemBrowser->setText( helpList[idx].problem );
    ui.solutionBrowser->setText( helpList[idx].solution );
}

void HelpDialog::next()
{
    if ( helpList.count() <= 1  )
        return;

    if ( m_idx == helpList.count() - 1 )
        viewHelp();
    else
        viewHelp( m_idx + 1 );
}

void HelpDialog::previous()
{
    if ( helpList.count() <= 1 )
        return;

    if ( m_idx == 0 )
        viewHelp( helpList.count() - 1 );
    else
        viewHelp( m_idx - 1 );
}

bool HelpDialog::getDontShowAgain()
{
    return ui.cbDontShowAgain->isChecked();
}

