#include "SoundModule.h"

extern "C" void module_init(Applet *applet)
{
    qDebug( "SoundModule: module_init." );
    soundModule = new SoundModule(applet);
}

extern "C" void module_exit()
{
    qDebug( "SoundModule: module_exit." );

    delete soundModule;
    soundModule = 0;
}

const QString SoundModule::soundsPath = UBUDSL_PREFIX + "/share/ubudsl/sounds";

SoundModule::SoundModule(Applet *parent )
:processThread(new ProcessThread(this)),
 sndConnected(soundsPath + "/connected.wav"),
 sndDisconnected(soundsPath + "/disconnected.wav"),
 sndError(soundsPath + "/error.wav"),
 sndPlugged(soundsPath + "/modem_plugged.wav"),
 sndUnplugged(soundsPath + "/modem_unplugged.wav")
{
    if ( parent == NULL )
    {
        qDebug( "SoundModule(): parent (Applet object) is NULL!" );
    }

    connect(parent, SIGNAL(playSndConnected()),    this, SLOT(playSndConnected()));
    connect(parent, SIGNAL(playSndDisconnected()), this, SLOT(playSndDisconnected()));
    connect(parent, SIGNAL(playSndError()),        this, SLOT(playSndError()));
    connect(parent, SIGNAL(playSndPlugged()),      this, SLOT(playSndPlugged()));
    connect(parent, SIGNAL(playSndUnplugged()),    this, SLOT(playSndUnplugged()));
}

void SoundModule::stop()
{
    if ( processThread->playProcess->state() != QProcess::NotRunning )
    {
        qDebug( "SoundModule::stop(): playProcess->state != QProcess::NotRunning" );
        processThread->playProcess->terminate();
    }
}

void SoundModule::playSndConnected()
{
    stop();

    processThread->playSound(sndConnected);
}

void SoundModule::playSndDisconnected()
{
    stop();

    processThread->playSound(sndDisconnected);
}

void SoundModule::playSndError()
{
    stop();

    processThread->playSound(sndError);
}

void SoundModule::playSndPlugged()
{
    stop();

    processThread->playSound(sndPlugged);
}

void SoundModule::playSndUnplugged()
{
    stop();

    processThread->playSound(sndUnplugged);
}

ProcessThread::ProcessThread(QObject *parent)
:QThread(parent),
 playProcess(new QProcess())
{
    playProcess->moveToThread(this);
}

void ProcessThread::playSound( const QString &soundPath )
{
    this->soundPath = soundPath;
    start();
}

void ProcessThread::run()
{
    playProcess->start("aplay", QStringList() << soundPath);
}

SoundModule *soundModule;
