/*
 * File: Firmware.h
 * Author: Adrian Łubik (2008)
 * License: GNU LGPL v3
 */

#ifndef FIRMWARE_H_
#define FIRMWARE_H_

#include <QProcess>
#include <QString>
#include <QStringList>
#include <QDir>
#include <QFileInfo>
#include <QThread>

/**
  * A class for extracting firmware from tar archives.
  */
class Firmware: public QObject
{
    Q_OBJECT
public:
    Firmware( QThread *parent = 0 );
    virtual ~Firmware();

    /**
      * Extracts given tar archive with the ueagle-atm firmware to /lib/firmware/ueagle-atm.
      * @return Returns true if the firmware has been successfully extracted.
      */
    bool installUeagleFirmware( const QString &tarArch )
    {
        return installFirmware( tarArch, "/lib/firmware/ueagle-atm" );
    }

    /**
      * Extracts given tar archive with the speedtouch based modems' firmware to /lib/firmware.
      * @return Returns true if the firmware has been successfully extracted.
      */
    bool installSpeedtchFirmware( const QString &tarArch )
    {
        return installFirmware( tarArch, "/lib/firmware" );
    }

    /**
      * Extracts given tar archive with the cxacru based modems' firmware to /lib/firmware.
      * @return Returns true if the firmware has been successfully extracted.
      */
    bool installCxacruFirmware( const QString &tarArch )
    {
        return installFirmware( tarArch, "/lib/firmware" );
    }

protected:
    /**
      * Extracts given tar archive with a firmware to given destPath.
      * @return Returns true if the firmware has been successfully extracted.
      */
    bool installFirmware( const QString &tarArch, const QString &destPath );
    QProcess *m_tarProc;
    QDir *m_destDir;
};

#endif /*FIRMWARE_H_*/
